==> ejc-assistrmat-api-3.0.0-20220525.091114-114-sources.jar: com/ejianc/business/assist/store/vo/OtherInDetailVO.java <==
package com.ejianc.business.assist.store.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 其他入库明细
 * 
 * @author generator
 * 
 */
public class OtherInDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long inId; // 入库ID
    private Long materialCategoryId; // 物资分类Id
    private String materialCategoryName; // 物资分类名称
    private Long materialId; // 物资Id
    private String materialCode; // 材料编码
    private String materialName; // 物资名称
    private String spec; // 规格型号
    private Long unit; // 计量单位
    private String unitName; // 计量单位
    private BigDecimal taxPrice; // 单价(含税)
    private BigDecimal price; // 单价(无税)
    private BigDecimal instoreMny; // 入库金额(无税)
    private BigDecimal instoreTaxMny; // 入库金额
    private BigDecimal instoreTax; // 入库税额
    private String memo; // 备注
    private BigDecimal inStoreNum; // 入库数量
    private BigDecimal taxRate; // 税率
    private BigDecimal transScale; // 转换系数
    private BigDecimal theoryWeight; // 理论重量
    private BigDecimal roughWeight; // 毛重
    private BigDecimal tareWeight; // 皮重
    private BigDecimal suttleWeight; // 净重
    private BigDecimal deviationRate; // 偏差率
    private Integer requirFlag; // 是否符合要求：0-否，1-是
    

    public Long getInId() {
        return inId;
    }

    public void setInId(Long inId) {
        this.inId = inId;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public Long getUnit() {
        return unit;
    }

    public void setUnit(Long unit) {
        this.unit = unit;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getTaxPrice() {
        return taxPrice;
    }

    public void setTaxPrice(BigDecimal taxPrice) {
        this.taxPrice = taxPrice;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getInstoreMny() {
        return instoreMny;
    }

    public void setInstoreMny(BigDecimal instoreMny) {
        this.instoreMny = instoreMny;
    }
    public BigDecimal getInstoreTaxMny() {
        return instoreTaxMny;
    }

    public void setInstoreTaxMny(BigDecimal instoreTaxMny) {
        this.instoreTaxMny = instoreTaxMny;
    }
    public BigDecimal getInstoreTax() {
        return instoreTax;
    }

    public void setInstoreTax(BigDecimal instoreTax) {
        this.instoreTax = instoreTax;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public BigDecimal getInStoreNum() {
        return inStoreNum;
    }

    public void setInStoreNum(BigDecimal inStoreNum) {
        this.inStoreNum = inStoreNum;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getTransScale() {
        return transScale;
    }

    public void setTransScale(BigDecimal transScale) {
        this.transScale = transScale;
    }
    public BigDecimal getTheoryWeight() {
        return theoryWeight;
    }

    public void setTheoryWeight(BigDecimal theoryWeight) {
        this.theoryWeight = theoryWeight;
    }
    public BigDecimal getRoughWeight() {
        return roughWeight;
    }

    public void setRoughWeight(BigDecimal roughWeight) {
        this.roughWeight = roughWeight;
    }
    public BigDecimal getTareWeight() {
        return tareWeight;
    }

    public void setTareWeight(BigDecimal tareWeight) {
        this.tareWeight = tareWeight;
    }
    public BigDecimal getSuttleWeight() {
        return suttleWeight;
    }

    public void setSuttleWeight(BigDecimal suttleWeight) {
        this.suttleWeight = suttleWeight;
    }
    public BigDecimal getDeviationRate() {
        return deviationRate;
    }

    public void setDeviationRate(BigDecimal deviationRate) {
        this.deviationRate = deviationRate;
    }
    public Integer getRequirFlag() {
        return requirFlag;
    }

    public void setRequirFlag(Integer requirFlag) {
        this.requirFlag = requirFlag;
    }
    
}

==> ejc-assistrmat-api-3.0.0-20221101.020733-293-sources.jar: com/ejianc/business/assist/store/vo/OtherInDetailVO.java <==
package com.ejianc.business.assist.store.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 其他入库明细
 * 
 * @author generator
 * 
 */
public class OtherInDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long inId; // 入库ID
    private Long materialCategoryId; // 物资分类Id
    private String materialCategoryName; // 物资分类名称
    private Long materialId; // 物资Id
    private String materialCode; // 材料编码
    private String materialName; // 物资名称
    private String spec; // 规格型号
    private Long unit; // 计量单位
    private String unitName; // 计量单位
    private BigDecimal taxPrice; // 单价(含税)
    private BigDecimal price; // 单价(无税)
    private BigDecimal instoreMny; // 入库金额(无税)
    private BigDecimal instoreTaxMny; // 入库金额
    private BigDecimal instoreTax; // 入库税额
    private String memo; // 备注
    private BigDecimal inStoreNum; // 入库数量
    private BigDecimal taxRate; // 税率
    private BigDecimal transScale; // 转换系数
    private BigDecimal theoryWeight; // 理论重量
    private BigDecimal roughWeight; // 毛重
    private BigDecimal tareWeight; // 皮重
    private BigDecimal suttleWeight; // 净重
    private BigDecimal deviationRate; // 偏差率
    private Integer requirFlag; // 是否符合要求：0-否，1-是
    private String flag;//标识
    private Long tonId; //理论重量单位
    

    public Long getInId() {
        return inId;
    }

    public void setInId(Long inId) {
        this.inId = inId;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public Long getUnit() {
        return unit;
    }

    public void setUnit(Long unit) {
        this.unit = unit;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getTaxPrice() {
        return taxPrice;
    }

    public void setTaxPrice(BigDecimal taxPrice) {
        this.taxPrice = taxPrice;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getInstoreMny() {
        return instoreMny;
    }

    public void setInstoreMny(BigDecimal instoreMny) {
        this.instoreMny = instoreMny;
    }
    public BigDecimal getInstoreTaxMny() {
        return instoreTaxMny;
    }

    public void setInstoreTaxMny(BigDecimal instoreTaxMny) {
        this.instoreTaxMny = instoreTaxMny;
    }
    public BigDecimal getInstoreTax() {
        return instoreTax;
    }

    public void setInstoreTax(BigDecimal instoreTax) {
        this.instoreTax = instoreTax;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public BigDecimal getInStoreNum() {
        return inStoreNum;
    }

    public void setInStoreNum(BigDecimal inStoreNum) {
        this.inStoreNum = inStoreNum;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getTransScale() {
        return transScale;
    }

    public void setTransScale(BigDecimal transScale) {
        this.transScale = transScale;
    }
    public BigDecimal getTheoryWeight() {
        return theoryWeight;
    }

    public void setTheoryWeight(BigDecimal theoryWeight) {
        this.theoryWeight = theoryWeight;
    }
    public BigDecimal getRoughWeight() {
        return roughWeight;
    }

    public void setRoughWeight(BigDecimal roughWeight) {
        this.roughWeight = roughWeight;
    }
    public BigDecimal getTareWeight() {
        return tareWeight;
    }

    public void setTareWeight(BigDecimal tareWeight) {
        this.tareWeight = tareWeight;
    }
    public BigDecimal getSuttleWeight() {
        return suttleWeight;
    }

    public void setSuttleWeight(BigDecimal suttleWeight) {
        this.suttleWeight = suttleWeight;
    }
    public BigDecimal getDeviationRate() {
        return deviationRate;
    }

    public void setDeviationRate(BigDecimal deviationRate) {
        this.deviationRate = deviationRate;
    }
    public Integer getRequirFlag() {
        return requirFlag;
    }

    public void setRequirFlag(Integer requirFlag) {
        this.requirFlag = requirFlag;
    }

    public String getFlag() {
        return flag;
    }

    public void setFlag(String flag) {
        this.flag = flag;
    }

    public Long getTonId() {
        return tonId;
    }

    public void setTonId(Long tonId) {
        this.tonId = tonId;
    }
}
